@@ -1485,10 +1485,11 @@ class ValidatorTestMixin(MetaSchemaTestsMixin, object):
         the interim, we haven't broken those users.
         """
 
-        @attr.s
-        class OhNo(self.Validator):
-            foo = attr.ib(factory=lambda: [1, 2, 3])
-            _bar = attr.ib(default=37)
+        with self.assertWarns(DeprecationWarning):
+            @attr.s
+            class OhNo(self.Validator):
+                foo = attr.ib(factory=lambda: [1, 2, 3])
+                _bar = attr.ib(default=37)
 
         validator = OhNo({}, bar=12)
         self.assertEqual(validator.foo, [1, 2, 3])
@@ -1906,6 +1907,10 @@ class TestValidatorFor(TestCase):
             validators.validator_for(schema={}, default={})
         self.assertFalse(w)
 
+    def test_validator_for_custom_default_with_schema(self):
+        schema, default = {"$schema": "mailto:foo@example.com"}, object()
+        self.assertIs(validators.validator_for(schema, default), default)
+
 
 class TestValidate(TestCase):
     def assertUses(self, schema, Validator):
